==> purchase-assist-domain-0.0.7-sources.jar: com/xforceplus/purchaserassist/entity/InvoiceInfo.java <==
package com.xforceplus.purchaserassist.entity;

import java.math.BigDecimal;
import com.baomidou.mybatisplus.annotation.TableName;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-03-17
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("invoiceInfo")
public class InvoiceInfo implements Serializable {

  private static final long serialVersionUID=1L;

  private String invoiceCode;

  private String invoiceNo;

  private String invoiceType;

  private Integer specialInvoiceFlag;

  private Integer status;

  private String paperDrewDate;

  private String taxRate;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private String purchaserName;

  private String purchaserTaxNo;

  private String sellerName;

  private String sellerTaxNo;

  private String machineCode;

  private String checkCode;

  private String cipherText;

  private String cashierName;

  private String checkerName;

  private String invoicerName;

  private String purchaserAddress;

  private String purchaserTel;

  private String purchaserAddrTel;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private String purchaserBankNameAccount;

  private String sellerAddress;

  private String sellerTel;

  private String sellerAddrTel;

  private String sellerBankName;

  private String sellerBankAccount;

  private String sellerBankNameAccount;

  private String remark;

  private String purchaserTenantCode;

  private Long purchaserTenantId;

  private Long purchaserCompanyId;

  private Long purchaserOrgId;

  private Long sellerTenantId;

  private Long sellerCompanyId;

  private Long sellerOrgId;

  private Integer redFlag;

  private String redNotificationNo;

  private String veriTaskId;

  private String veriRemark;

  private Integer veriStatus;

  private LocalDateTime veriRequestTime;

  private LocalDateTime veriResponseTime;

  private Integer invoiceOrig;

  private Integer isDelete;

  private Integer distributeFlag;

  private Integer processFlag;

  private Integer invoiceFlag;

  private Integer discernFlag;

  private Integer uniqueFlag;

  private Long collectionId;

  private Long userId;

  private String imgUrl;

  private String invoiceCodeP;

  private String invoiceNoP;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private String createUser;

  private String updateUser;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;




        }

==> purchase-assist-domain-0.0.14-sources.jar: com/xforceplus/purchaserassist/entity/InvoiceInfo.java <==
package com.xforceplus.purchaserassist.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-04-02
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class InvoiceInfo implements Serializable {

  private static final long serialVersionUID=1L;

  private String invoiceCode;

  private String invoiceNo;

  private String invoiceType;

  private Integer specialInvoiceFlag;

  private Integer status;

  private String paperDrewDate;

  private String taxRate;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private String purchaserName;

  private String purchaserTaxNo;

  private String sellerName;

  private String sellerTaxNo;

  private String machineCode;

  private String checkCode;

  private String cipherText;

  private String cashierName;

  private String checkerName;

  private String invoicerName;

  private String purchaserAddress;

  private String purchaserTel;

  private String purchaserAddrTel;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private String purchaserBankNameAccount;

  private String sellerAddress;

  private String sellerTel;

  private String sellerAddrTel;

  private String sellerBankName;

  private String sellerBankAccount;

  private String sellerBankNameAccount;

  private String remark;

  private String purchaserTenantCode;

  private Long purchaserTenantId;

  private Long purchaserCompanyId;

  private Long purchaserOrgId;

  private Long sellerTenantId;

  private Long sellerCompanyId;

  private Long sellerOrgId;

  private Integer redFlag;

  private String redNotificationNo;

  private String veriTaskId;

  private String veriRemark;

  private Integer veriStatus;

  private LocalDateTime veriRequestTime;

  private LocalDateTime veriResponseTime;

  private Integer invoiceOrig;

  private Integer isDelete;

  private Integer distributeFlag;

  private Integer processFlag;

  private Integer invoiceFlag;

  private Integer discernFlag;

  private Integer uniqueFlag;

  private Long collectionId;

  private Long userId;

  private String imgUrl;

  private String invoiceCodeP;

  private String invoiceNoP;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;




        }
